<?php

function node_invite_send() {
	global $user;

	// make sure that arg(2) exists and that is's a number.
	$nid = arg(2);
	if ( !intval($nid) ) {
		drupal_set_message("$nid is not a number.  This form should only be called with a node-id as the 2nd argument in the URL.",'error');
		return;
	}

	$form['your_name'] = array(
		'#title' => t('Your Name'),
		'#type' => 'textfield',
		'#default_value' => $user->name,
	);
	$form['your_email'] = array(
		'#title' => t('Your E-mail Address'),
		'#type' => 'textfield',
		'#default_value' => $user->mail,
	);
	$form['personal_message'] = array(
		'#title' => t('Personal Message'),
		'#type' => 'textarea',
	);
	$form['emails'] = array(
		'#title' => t('Email Addresses for Delivery'),
		'#type' => 'textarea',
		'#description' => t('One address per line please'),
	);
	$form['nid'] = array(
		'#default_value' => $nid,
		'#type' => 'hidden',
	);
	$form['submit'] = array(
		'#type' => 'submit',
		'#value' => t('Submit'),
	);

	return $form;
}

function node_invite_send_validate( &$form, $form_state ) {
	// validate sender
	if ( !valid_email_address($form_state['values']['your_email']) ) {
		form_set_error('your_email',$form_state['values']['your_email'].' is not a valid email address');
	}
	// validate recipients
	$emails = preg_split("/[
\n]/", $form_state['values']['emails'] );
	foreach ($emails as $email ) {
		$split = preg_split('/\s*\|\s*/',$email);
		if ( count($split) == 2 ) {
			$email = $split[1];
		}
		if ( $email != '' && !valid_email_address($email) ) {
			form_set_error('emails',"$email is not a valid email address");
		}
	}
}

function node_invite_send_submit( $form, &$form_state ) {
	global $user;

	// 1. Grab default message
	$default_message = variable_get('node_invite_message_default',NODE_INVITE_MESSAGE_DEFAULT);

	// 2. Load the node
	$node = node_load( $form_state['values']['nid'] ) ;

	// 3. do emails
	$emails = preg_split("/[
\n]/", $form_state['values']['emails'] );
	foreach ($emails as $email ) {
		// on my mac, that preg_split makes:
		// array( 'a@b.c','',d@e.f','','g@h.i');
		// the empty check fixes that weirdness
		if ( $email != '' ) {
			$split = preg_split('/\s*\|\s*/',$email);
			if ( count($split) == 2 ) {
				$email = "$split[0] <$split[1]>";
			}
			watchdog('node_invite', 'TO: ' . check_plain( $email) );

			// 4. store a record in {node_invites} and get insrt_id (which we use to build the message)
			db_query("INSERT INTO {node_invites} ( nid,email_invitee,uid_inviter,status,sent ) VALUES ( %d,'%s',%d,'%s',%d )", $form_state['values']['nid'], $email, $user->uid, 'NEW', time());
			$insert_id = db_last_insert_id('node_invites','iid');
	
			// 5. build the email message for this user (link is different for every specific message... which is slow (re-parse every single message)
			$inviter_rsvp_url = url( 'node_invite/rsvp/' . $form_state['values']['nid'] . '/' . $insert_id, array('absolute' => TRUE) );
			$new_default_message = str_replace("[inviter-rsvp-url]", $inviter_rsvp_url, $default_message);
			$replaced_message = token_replace( $new_default_message, 'node', $node );
			$replaced_message .= "\n<BR>" . $form_state['values']['personal_message'];
			$subj = token_replace( 
				variable_get('node_invite_subject_default',NODE_INVITE_SUBJECT_DEFAULT),
				'node',
				$node 
			);
	
			$msg = drupal_mail(
				// module
				'node_invite',
				// key
				'invite',
				// to
				$email,
				// language
				language_default(),
				// params
				array(
					'subject'	=> $subj,
					'body'		=> $replaced_message,
				),
				// from
				$form_state['values']['your_email'],
				// send
				TRUE
			);
		}
	}
	
	// send them somewhere... back to the node!
	$form_state['redirect'] = "node/" . $form_state['values']['nid'];
}

